@@ -3,7 +3,7 @@ package Crypt::KeyWrap;
 use strict;
 use warnings;
 
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 use Exporter 'import';
 our %EXPORT_TAGS = ( all => [qw(aes_key_wrap aes_key_unwrap gcm_key_wrap gcm_key_unwrap pbes2_key_wrap pbes2_key_unwrap ecdh_key_wrap ecdh_key_unwrap ecdhaes_key_wrap ecdhaes_key_unwrap rsa_key_wrap rsa_key_unwrap)] );
@@ -15,6 +15,7 @@ use Crypt::AuthEnc::GCM qw(gcm_encrypt_authenticate gcm_decrypt_verify);
 use Crypt::PRNG qw(random_bytes);
 use Crypt::KeyDerivation qw(pbkdf2);
 use Crypt::Digest qw(digest_data);
+use Config;
 
 # JWS: https://tools.ietf.org/html/rfc7515
 # JWE: https://tools.ietf.org/html/rfc7516
@@ -35,8 +36,11 @@ sub _MSB {
 
 sub _N2RAW {
   my ($bytes, $n) = @_;
-  return pack("N", $n >> 32) . pack("N", $n & 0xFFFFFFFF) if $bytes == 8;
-  return pack("N", $n& 0xFFFFFFFF) if $bytes == 4;
+  if ($bytes == 8) {
+    return pack("N", 0) . pack("N", $n) if $Config{uvsize} == 4; #workaround
+    return pack("N", $n >> 32) . pack("N", $n & 0xFFFFFFFF);
+  }
+  return pack("N", $n & 0xFFFFFFFF) if $bytes == 4;
 }
 
 sub aes_key_wrap {
